/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apithefire.servlet.embedded;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Enumeration;
import java.util.List;

import javax.servlet.Filter;
import javax.servlet.FilterConfig;
import javax.servlet.Servlet;
import javax.servlet.ServletConfig;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;

import org.apithefire.util.lang.Objects;

// TODO: should make it ContainerServlet and have servlets extend it
class ServletAndFilterContainer {
	
	private static class ContextAndNameConfig implements ServletConfig,
			FilterConfig {
		
		private final ServletContext servletContext;
		private final String name;
		
		public ContextAndNameConfig(ServletContext servletContext,
				String name) {
			this.servletContext = Objects.nonNull(servletContext);
			this.name = Objects.nonNull(name);
		}

		public ServletContext getServletContext() {
			return servletContext;
		}

		public String getServletName() {
			return name;
		}

		public String getFilterName() {
			return name;
		}

		public String getInitParameter(String name) {
			return null;
		}

		public Enumeration<String> getInitParameterNames() {
			List<String> emptyList = Collections.emptyList();
			return Collections.enumeration(emptyList);
		}
		
	}
	
	private final List<Object> servletsAndFilters = new ArrayList<Object>();
	
	public boolean contains(Object servletOrFilter) {
		return servletsAndFilters.contains(servletOrFilter);
	}
	
	public int getCount() {
		return servletsAndFilters.size();
	}
	
	public void add(Object servletOrFilter) {
		if (!(servletOrFilter instanceof Servlet)
				&& !(servletOrFilter instanceof Filter)) {
			throw new IllegalArgumentException(
					"Not a servlet and not a filter.");
		}
		Objects.nonNull(servletOrFilter);
		
		if (!servletsAndFilters.contains(servletOrFilter)) {
			servletsAndFilters.add(servletOrFilter);
		}
	}
	
	public void addAll(Collection<?> servletsAndFilters) {
		for (Object servletOrFilter : servletsAndFilters) {
			add(servletOrFilter);
		}
	}
	
	public void remove(Object servletOrFilter) {
		servletsAndFilters.remove(servletOrFilter);
	}

	public void init(ServletContext servletContext) throws ServletException {
		for (Object servletOrFilter : servletsAndFilters) {
			if (servletOrFilter instanceof Servlet) {
				Servlet servlet = (Servlet) servletOrFilter;
				
				servlet.init(new ContextAndNameConfig(servletContext, servlet
						.toString()));
			} else if (servletOrFilter instanceof Filter) {
				Filter filter = (Filter) servletOrFilter;

				filter.init(new ContextAndNameConfig(servletContext, filter
						.toString()));
			}
		}
	}

	public void destroy() {
		// TODO: MultiException
		for (Object servletOrFilter : servletsAndFilters) {
			if (servletOrFilter instanceof Servlet) {
				((Servlet) servletOrFilter).destroy();
			} else if (servletOrFilter instanceof Filter) {
				((Filter) servletOrFilter).destroy();
			}
		}
	}

}
