/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apithefire.servlet.embedded;

import java.util.Set;

/**
 * Represents a user scope.
 * 
 * @author <a href="mailto:bachew@gmail.com">Chew Boon Aik</a>
 */
public interface Session {
	
	/**
	 * Returns this session id.
	 */
	public String getId();
	
	/**
	 * Returns attribute keys of this session.
	 */
	public Set<String> getAttributeKeys();

	/**
	 * Returns attribute value of the specified key from this session.
	 */
	public Object getAttributeValue(String key);
	
	/**
	 * Sets attribute into this session.
	 * @param key attribute key.
	 * @param value attribute value.
	 */
	public void setAttribute(String key, Object value);
	
	/**
	 * Removes attribute of the specified key from this session.
	 */
	public void removeAttribute(String key);

}
