/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apithefire.servlet.embedded;

/**
 * A session manager is responsible for session creation, persistence and
 * removal.
 * 
 * @author <a href="mailto:bachew@gmail.com">Chew Boon Aik</a>
 */
public interface SessionManager {

	/**
	 * Creates a new session and persist it.
	 * 
	 * @return created session.
	 */
	public Session createSession();
	
	/**
	 * Returns persisted session of the specified id.
	 * 
	 * @throws IllegalArgumentException if {@code sessionId} is invalid.
	 */
	public Session getSession(String sessionId);
	
	/**
	 * Remove persisted session of the specified id.
	 * 
	 * @throws IllegalArgumentException if {@code sessionId} is invalid.
	 */
	public void removeSession(String sessionId);
	
}
