/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apithefire.servlet.server;

import javax.servlet.Servlet;

import org.apithefire.util.lang.Path;

/**
 * A {@link Server} builder.
 * 
 * @author <a href="mailto:bachew@gmail.com">Chew Boon Aik</a>
 */
public abstract class AbstractServerBuilder implements ServerBuilder {
	
	public ServerBuilder addConnector() {
		addConnectorBuilder();
		return this;
	}
	
	public ServerBuilder addConnector(int port) {
		addConnectorBuilder().setPort(port);
		return this;
	}

	public ServerBuilder addSecureConnector() {
		addSecureConnectorBuilder();
		return this;
	}
	
	public ServerBuilder addContext(Servlet servlet) {
		addContextBuilder().setServlet(servlet);
		return this;
	}
	
	public ServerBuilder addContext(Path path, Servlet servlet) {
		addContextBuilder().setPath(path).setServlet(servlet);
		return this;
	}
	
}
