/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apithefire.servlet.server;

import javax.servlet.Servlet;

import org.apithefire.servlet.RuntimeServletException;
import org.apithefire.util.lang.Builder;
import org.apithefire.util.lang.Path;

/**
 * A context builder returned from {@link ServerBuilder#addContextBuilder()}.
 * 
 * @author <a href="mailto:bachew@gmail.com">Chew Boon Aik</a>
 */
public interface ContextBuilder extends Builder {
	
	/**
	 * Default context path, {@code Path.EMPTY_PATH}.
	 */
	public static final Path DEFAULT_PATH = Path.EMPTY_PATH;
	
	/**
	 * Sets context path.
	 * 
	 * @see #DEFAULT_PATH
	 */
	public ContextBuilder setPath(Path path);
	
	/**
	 * Sets context servlet.
	 */
	public ContextBuilder setServlet(Servlet servlet);
	
	/**
	 * Builds a new context.
	 * 
	 * @return the built context.
	 * @throws RuntimeServletException if servlet is not set.
	 */
	public Object build();
	
}
