/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apithefire.servlet.server;

import javax.servlet.Servlet;

import org.apithefire.servlet.server.ConnectorBuilder;
import org.apithefire.servlet.server.ContextBuilder;
import org.apithefire.servlet.server.SecureConnectorBuilder;
import org.apithefire.util.lang.Builder;
import org.apithefire.util.lang.Path;

/**
 * A {@link Server} builder.
 * 
 * @author <a href="mailto:bachew@gmail.com">Chew Boon Aik</a>
 */
public interface ServerBuilder extends Builder {

	/**
	 * Adds a new connector.
	 * 
	 * @return builder of the added connector
	 */
	public ConnectorBuilder addConnectorBuilder();
	
	/**
	 * Adds a new connector.
	 * 
	 * @return this builder
	 */
	public ServerBuilder addConnector();
	
	/**
	 * Equivalent to
	 * {@link ConnectorBuilder#setPort(int) addConnectorBuilder().setPort(port)}
	 * but with this builder returned.
	 * 
	 * @return this builder
	 */
	public ServerBuilder addConnector(int port);
	
	/**
	 * Adds a new secure connector.
	 * 
	 * @return builder of the added secure connector
	 */
	public SecureConnectorBuilder addSecureConnectorBuilder();

	/**
	 * Adds a new secure connector.
	 * 
	 * @return this builder
	 */
	public ServerBuilder addSecureConnector();
	
	/**
	 * Adds a new context.
	 * 
	 * @return builder of the added context
	 */
	public ContextBuilder addContextBuilder();
	
	/**
	 * Adds a new context.
	 * 
	 * @param servlet context servlet 
	 * @return this builder
	 */
	public ServerBuilder addContext(Servlet servlet);
	
	/**
	 * Adds a new context.
	 * 
	 * @param path context path
	 * @param servlet context servlet
	 * @return this builder
	 */
	public ServerBuilder addContext(Path path, Servlet servlet);
	
	/**
	 * Builds  a new {@link Server}.
	 * 
	 * @return the built {@link Server}
	 */
	public Server build();
	
}
